Blueprint API
#############

The Blueprint API is used to create and manage blueprints.

.. seealso::

    :doc:`api-orchestration`

Blueprint Components
--------------------

.. autosummary::
   :toctree: generated/

   cstar.orchestration.models.ConfiguredBaseModel
   cstar.orchestration.models.Resource
   cstar.orchestration.models.VersionedResource
   cstar.orchestration.models.Dataset
   cstar.orchestration.models.PathFilter
   cstar.orchestration.models.CodeRepository
   cstar.orchestration.models.ParameterSet
   cstar.orchestration.models.Blueprint

Simulation Components
---------------------

.. autosummary::
   :toctree: generated/

   cstar.orchestration.models.ForcingConfiguration
   cstar.orchestration.models.BlueprintState
   cstar.orchestration.models.RuntimeParameterSet
   cstar.orchestration.models.PartitioningParameterSet
   cstar.orchestration.models.ModelParameterSet

ROMS-MARBL
----------

.. autosummary::
   :toctree: generated/

   cstar.orchestration.models.ROMSCompositeCodeRepository
   cstar.orchestration.models.RomsMarblBlueprint
